@@ -1,6 +1,5 @@
-from jms_utils.frozen import cwd
 from jms_utils.logger import log_format_string
-from jms_utils.paths import ChDir
+from jms_utils.paths import ChDir, cwd
 from jms_utils.system import get_system
 from jms_utils.terminal import (get_terminal_size,
                                 terminal_formatter)
